From aca3862b4d9ce2d5af93af5011dd855f8cd175f3 Mon Sep 17 00:00:00 2001
From: TheNoctambulist <TheNoctambulist@example.com>
Date: Sun, 7 Sep 2014 11:33:56 +0930
Subject: [PATCH] Fix for variables and if statements in macros.

---
 IR Server Suite/Common/IrssUtils/Common.cs    | 27 +++++++++++++++++++++++----
 IR Server Suite/Common/IrssUtils/IrssMacro.cs |  6 +++---
 2 files changed, 26 insertions(+), 7 deletions(-)

diff --git a/IR Server Suite/Common/IrssUtils/Common.cs b/IR Server Suite/Common/IrssUtils/Common.cs
index 584958b..d36bc89 100644
--- a/IR Server Suite/Common/IrssUtils/Common.cs	
+++ b/IR Server Suite/Common/IrssUtils/Common.cs	
@@ -815,7 +815,7 @@ namespace IrssUtils
       if (commands == null)
         throw new ArgumentNullException("commands");
 
-      Uri uri = new Uri(ReplaceSpecial(commands[0]).ToString());
+      Uri uri = new Uri(ReplaceSpecialVariables(commands[0]));
 
       WebRequest request = WebRequest.Create(uri);
       request.Timeout = int.Parse(commands[1]);
@@ -1023,17 +1023,18 @@ namespace IrssUtils
     }
 
     /// <summary>
-    /// Replace all instances of environment variables, special values and escape codes.
+    /// Replace all instances of environment variables and special values.
     /// </summary>
     /// <param name="input">The input to process.</param>
     /// <returns>Processed input string.</returns>
-    public static Byte[] ReplaceSpecial(string input)
+    public static string ReplaceSpecialVariables(string input)
     {
       if (String.IsNullOrEmpty(input))
       {
-        return null;
+        return String.Empty;
       }
 
+
       // Process Special Codes ...
       if (input.Contains("%"))
       {
@@ -1107,6 +1108,24 @@ namespace IrssUtils
         }
       }
 
+      return input;
+    }
+
+    /// <summary>
+    /// Replace all instances of environment variables, special values and escape codes.
+    /// </summary>
+    /// <param name="input">The input to process.</param>
+    /// <returns>Processed input string.</returns>
+    public static Byte[] ReplaceSpecial(string input)
+    {
+      if (String.IsNullOrEmpty(input))
+      {
+        return new byte[0];
+      }
+
+      // Process Special Codes ...
+      input = ReplaceSpecialVariables(input);
+
       // Process Escape Codes ...
       bool inEscapeCode = false;
       bool inHexCode = false;
diff --git a/IR Server Suite/Common/IrssUtils/IrssMacro.cs b/IR Server Suite/Common/IrssUtils/IrssMacro.cs
index 2d76260..91efbad 100644
--- a/IR Server Suite/Common/IrssUtils/IrssMacro.cs	
+++ b/IR Server Suite/Common/IrssUtils/IrssMacro.cs	
@@ -177,11 +177,11 @@ namespace IrssUtils
 
           if (commands[0].StartsWith(Common.VariablePrefix, StringComparison.OrdinalIgnoreCase))
             commands[0] = variables.GetVariable(commands[0].Substring(Common.VariablePrefix.Length));
-          commands[0] = Common.ReplaceSpecial(commands[0]).ToString();
+          commands[0] = Common.ReplaceSpecialVariables(commands[0]);
 
           if (commands[2].StartsWith(Common.VariablePrefix, StringComparison.OrdinalIgnoreCase))
             commands[2] = variables.GetVariable(commands[2].Substring(Common.VariablePrefix.Length));
-          commands[2] = Common.ReplaceSpecial(commands[2]).ToString();
+          commands[2] = Common.ReplaceSpecialVariables(commands[2]);
 
           if (EvaluateIfCommand(commands))
             position = GetLabelPosition(commandList, commands[3]);
@@ -202,7 +202,7 @@ namespace IrssUtils
           string[] commands = Common.SplitSetVarCommand(command.Substring(Common.CmdPrefixSetVar.Length));
 
           string variable = commands[0].Substring(Common.VariablePrefix.Length);
-          string value = Common.ReplaceSpecial(commands[1]).ToString();
+          string value = Common.ReplaceSpecialVariables(commands[1]);
 
           variables.SetVariable(variable, value);
         }
-- 
1.8.1.msysgit.1

